@@ -1,9 +1,7 @@
-from __future__ import absolute_import
-from __future__ import unicode_literals
-
 import functools
 import inspect
 import logging
+import warnings
 from operator import attrgetter
 
 import flask
@@ -509,6 +507,7 @@ class RelationshipMultipleField(RelationshipFieldBase, SelectMultipleField):
     """
     def __init__(self, label, orm_cls, label_attr=None,
                  query_filter=None, coerce=_not_given, **kwargs):
+        coerce = coerce or self.coerce_to_int
         super().__init__(label, orm_cls, label_attr, None, query_filter, coerce, **kwargs)
 
     def get_data_filter(self):
@@ -519,6 +518,44 @@ class RelationshipMultipleField(RelationshipFieldBase, SelectMultipleField):
         existing_ids = [obj.id for obj in self.data]
         return self.orm_cls.id.in_(existing_ids)
 
+    @staticmethod
+    def coerce_to_int(value):
+        return int(value)
+
+    def coerce_to_obj(self, value):
+        if type(value) in [int, str]:
+            return self.orm_cls.query.get(int(value))
+        else:
+            return value
+
+    def iter_choices(self):
+        selected_ids = [v.id for v in self.data or []]
+        for value, label in self.choices():
+            selected = selected_ids is not None and self.coerce(value) in selected_ids
+            yield (value, label, selected)
+
+    def process_formdata(self, valuelist):
+        try:
+            self.data = list(self.coerce_to_obj(v) for v in valuelist)
+        except ValueError:
+            raise ValueError(self.gettext('Invalid Choice: could not coerce'))
+
+    def process_data(self, value):
+        try:
+            self.data = list(v for v in value)
+        except (ValueError, TypeError):
+            self.data = None
+
+    def pre_validate(self, form):
+        if self.data:
+            values = list(c[0] for c in self.choices())
+            for d in self.data:
+                if str(d.id) not in values:
+                    raise ValueError(
+                        self.gettext("'%(value)s' is not a valid choice for this field")
+                        % dict(value=d)
+                    )
+
 
 class _TypeHintingTextInputBase(wtforms.widgets.TextInput):
     def __init__(self, prefix=None, suffix=None):
@@ -714,7 +751,7 @@ def form_validator(func=None, only_when_fields_valid=False):
 
     @functools.wraps(func)
     def wrapper(form):
-        if not only_when_fields_valid or not form.field_errors:
+        if not only_when_fields_valid or not form.errors:
             return func(form)
 
     global ___validator_creation_counter
@@ -796,36 +833,25 @@ class Form(BaseForm):
             }
             form_validators.update(cls_validators)
 
-        self._form_level_errors = []
         for validator in sorted(form_validators.values(), key=attrgetter('___creation_counter')):
             try:
                 validator(self)
             except StopValidation as e:
                 if e.args and e.args[0]:
-                    self._form_level_errors.append(e.args[0])
+                    self.form_errors.append(e.args[0])
                 break
             except ValueError as e:
-                self._form_level_errors.append(e.args[0])
+                self.form_errors.append(e.args[0])
 
-        return fields_valid and not self._form_level_errors
-
-    @property
-    def form_errors(self):
-        """Form-level validator errors will be logged in this list."""
-        return self._form_level_errors
+        return fields_valid and not self.form_errors
 
     @property
     def field_errors(self):
         """Field-level validator errors come from WTForms' errors."""
-        return super().errors
-
-    @property
-    def errors(self):
-        """Field-level errors, plus form-level errors under the key "_form"."""
-        errors = self.field_errors
-        if self.form_errors:
-            errors['_form'] = self.form_errors
-        return errors
+        warnings.warn(
+            'WTForms has form-level validation now, use form.errors instead', DeprecationWarning, 2
+        )
+        return self.errors
 
 
 BaseModelFormMeta = model_form_meta_factory()
